@@ -13,6 +13,7 @@ class RemoteEnv(BaseEnv):
     """The remote machine's environment; exposes a dict-like interface"""
 
     __slots__ = ["_orig", "remote"]
+
     def __init__(self, remote):
         self.remote = remote
         session = remote._session
@@ -105,7 +106,7 @@ class RemoteCommand(ConcreteCommand):
     def __init__(self, remote, executable, encoding = "auto"):
         self.remote = remote
         ConcreteCommand.__init__(self, executable,
-            remote.encoding if encoding == "auto" else encoding)
+            remote.custom_encoding if encoding == "auto" else encoding)
     @property
     def machine(self):
         return self.remote
@@ -115,13 +116,13 @@ class RemoteCommand(ConcreteCommand):
         return self.remote.popen(self[args], **kwargs)
     def nohup(self, cwd='.', stdout='nohup.out', stderr=None, append=True):
         """Runs a command detached."""
-        return machine.nohup(self, cwd, stdout, stderr, append)
+        return self.machine.daemonic_popen(self, cwd, stdout, stderr, append)
 
 class ClosedRemoteMachine(Exception):
     pass
 
 class ClosedRemote(object):
-    __slots__ = ["_obj"]
+    __slots__ = ["_obj", "__weakref__"]
     def __init__(self, obj):
         self._obj = obj
     def close(self):
@@ -139,19 +140,24 @@ class BaseRemoteMachine(BaseMachine):
 
     * ``cwd`` - the remote working directory
     * ``env`` - the remote environment
-    * ``encoding`` - the remote machine's default encoding (assumed to be UTF8)
+    * ``custom_encoding`` - the remote machine's default encoding (assumed to be UTF8)
     * ``connect_timeout`` - the connection timeout
+
+
+    There also is a _cwd attribute that exists if the cwd is not current (del if cwd is changed).
     """
 
     # allow inheritors to override the RemoteCommand class
     RemoteCommand = RemoteCommand
-    
+
     @property
     def cwd(self):
-        return RemoteWorkdir(self)
+        if not hasattr(self, '_cwd'):
+            self._cwd = RemoteWorkdir(self)
+        return self._cwd
 
     def __init__(self, encoding = "utf8", connect_timeout = 10, new_session = False):
-        self.encoding = encoding
+        self.custom_encoding = encoding
         self.connect_timeout = connect_timeout
         self._session = self.session(new_session = new_session)
         self.uname = self._get_uname()
@@ -215,7 +221,7 @@ class BaseRemoteMachine(BaseMachine):
         for name in alternatives:
             for p in self.env.path:
                 fn = p / name
-                if fn.access("x"):
+                if fn.access("x") and not fn.is_dir():
                     return fn
 
         raise CommandNotFound(progname, self.env.path)
@@ -350,6 +356,8 @@ class BaseRemoteMachine(BaseMachine):
         self._session.run("mkdir -p %s" % (shquote(fn),))
     def _path_chmod(self, mode, fn):
         self._session.run("chmod %o %s" % (mode, shquote(fn)))
+    def _path_touch(self, path):
+        self._session.run("touch {path}".format(path=path))
     def _path_chown(self, fn, owner, group, recursive):
         args = ["chown"]
         if recursive:
@@ -365,12 +373,12 @@ class BaseRemoteMachine(BaseMachine):
 
     def _path_read(self, fn):
         data = self["cat"](fn)
-        if self.encoding and isinstance(data, six.unicode_type):
-            data = data.encode(self.encoding)
+        if self.custom_encoding and isinstance(data, six.unicode_type):
+            data = data.encode(self.custom_encoding)
         return data
     def _path_write(self, fn, data):
-        if self.encoding and isinstance(data, six.unicode_type):
-            data = data.encode(self.encoding)
+        if self.custom_encoding and isinstance(data, six.unicode_type):
+            data = data.encode(self.custom_encoding)
         with NamedTemporaryFile() as f:
             f.write(data)
             f.flush()
