@@ -5,7 +5,7 @@ import shutil
 import errno
 import logging
 from contextlib import contextmanager
-from plumbum.lib import _setdoc, IS_WIN32
+from plumbum.lib import _setdoc, IS_WIN32, six
 from plumbum.path.base import Path, FSUser
 from plumbum.path.remote import RemotePath
 try:
@@ -23,7 +23,7 @@ except ImportError:
 
 try: # Py3
     import urllib.parse as urlparse
-    import urllib.request as urllib 
+    import urllib.request as urllib
 except ImportError:
     import urlparse
     import urllib
@@ -46,7 +46,7 @@ class LocalPath(Path):
                 not isinstance(parts[0], LocalWorkdir):
             return parts[0]
         if not parts:
-            raise TypeError("At least one path part is require (none given)")
+            raise TypeError("At least one path part is required (none given)")
         if any(isinstance(path, RemotePath) for path in parts):
             raise TypeError("LocalPath cannot be constructed from %r" % (parts,))
         self = super(LocalPath, cls).__new__(cls, os.path.normpath(os.path.join(*(str(p) for p in parts))))
@@ -57,8 +57,6 @@ class LocalPath(Path):
 
     def _get_info(self):
         return self._path
-    def __getstate__(self):
-        return {"_path" : self._path}
 
     def _form(self, *parts):
         return LocalPath(*parts)
@@ -110,12 +108,12 @@ class LocalPath(Path):
     @_setdoc(Path)
     def list(self):
         return [self / fn for fn in os.listdir(str(self))]
-        
+
     @_setdoc(Path)
     def iterdir(self):
         try:
-            return (self.__class__(fn.name) for fn in os.scandir(str(self)))
-        except NameError:
+            return (self / fn.name for fn in os.scandir(str(self)))
+        except AttributeError:
             return (self / fn for fn in os.listdir(str(self)))
 
     @_setdoc(Path)
@@ -160,7 +158,7 @@ class LocalPath(Path):
     @_setdoc(Path)
     def glob(self, pattern):
         fn = lambda pat: [LocalPath(m) for m in glob.glob(str(self / pat))]
-        return self._glob(pattern, fn) 
+        return self._glob(pattern, fn)
 
     @_setdoc(Path)
     def delete(self):
@@ -171,7 +169,7 @@ class LocalPath(Path):
         else:
             try:
                 os.remove(str(self))
-            except OSError:
+            except OSError: # pragma: no cover
                 # file might already been removed (a race with other threads/processes)
                 _, ex, _ = sys.exc_info()
                 if ex.errno != errno.ENOENT:
@@ -185,10 +183,12 @@ class LocalPath(Path):
         return LocalPath(dst)
 
     @_setdoc(Path)
-    def copy(self, dst, override = False):
+    def copy(self, dst, override = False, overwrite = True):
         if isinstance(dst, RemotePath):
             raise TypeError("Cannot copy local path %s to %r" % (self, dst))
         dst = LocalPath(dst)
+        if not overwrite and dst.exists():
+            raise TypeError("File exists and override was not specified")
         if override:
             dst.delete()
         if self.is_dir():
@@ -205,31 +205,43 @@ class LocalPath(Path):
         if not self.exists():
             try:
                 os.makedirs(str(self))
-            except OSError:
+            except OSError: # pragma: no cover
                 # directory might already exist (a race with other threads/processes)
                 _, ex, _ = sys.exc_info()
                 if ex.errno != errno.EEXIST:
                     raise
 
     @_setdoc(Path)
-    def open(self, mode = "rb"):
+    def open(self, mode = "r"):
         return open(str(self), mode)
 
     @_setdoc(Path)
-    def read(self, encoding=None):
-        with self.open("rb") as f:
+    def read(self, encoding=None, mode = 'r'):
+        if encoding and 'b' not in mode:
+            mode = mode + 'b'
+        with self.open(mode) as f:
             data = f.read()
             if encoding:
                 data = data.decode(encoding)
             return data
 
     @_setdoc(Path)
-    def write(self, data, encoding=None):
+    def write(self, data, encoding=None, mode = None):
         if encoding:
             data = data.encode(encoding)
-        with self.open("wb") as f:
+        if mode is None:
+            if isinstance(data, six.unicode_type):
+                mode = 'w'
+            else:
+                mode = 'wb'
+        with self.open(mode) as f:
             f.write(data)
 
+    @_setdoc(Path)
+    def touch(self):
+        with open(str(self), 'a'):
+            os.utime(str(self), None)
+
     @_setdoc(Path)
     def chown(self, owner = None, group = None, recursive = None):
         if not hasattr(os, "chown"):
@@ -287,7 +299,7 @@ class LocalPath(Path):
             else:
                 # windows: use rmdir for directories and directory symlinks
                 os.rmdir(str(self))
-        except OSError:
+        except OSError: # pragma: no cover
             # file might already been removed (a race with other threads/processes)
             _, ex, _ = sys.exc_info()
             if ex.errno != errno.ENOENT:
@@ -306,7 +318,7 @@ class LocalPath(Path):
     @_setdoc(Path)
     def root(self):
         return os.path.sep
-    
+
 
 
 class LocalWorkdir(LocalPath):
@@ -336,12 +348,12 @@ class LocalWorkdir(LocalPath):
         """A context manager used to ``chdir`` into a directory and then ``chdir`` back to
         the previous location; much like ``pushd``/``popd``.
 
-        :param newdir: The destination director (a string or a ``LocalPath``)
+        :param newdir: The destination directory (a string or a ``LocalPath``)
         """
         prev = self._path
         newdir = self.chdir(newdir)
         try:
-            yield newdir 
+            yield newdir
         finally:
             self.chdir(prev)
 
